# @warriorpy/units

> Warriorpy official units.

### Archer

- **Character:** a
- **Max Health:** 7 HP
- **Abilities:**
  - look (3 range)
  - shoot (3 range, 3 power)
- **AI:** Attack first enemy in line of sight in any direction.

### Captive

- **Character:** C
- **Max Health:** 1 HP
- **Abilities:** None.
- **AI:** Wait to be rescued.

### Sludge

- **Character:** s
- **Max Health:** 12 HP
- **Abilities:**
  - feel
  - attack (3 power)
- **AI:** Attack first adjacent enemy in any direction.

### Thick Sludge

- **Character:** S
- **Max Health:** 24 HP
- **Abilities:**
  - feel
  - attack (3 power)
- **AI:** Attack first adjacent enemy in any direction.

### Warrior

- **Character:** @
- **Max Health:** 20 HP
- **Abilities:** Determined by the level.
- **AI:** Provided by the player.

### Wizard

- **Character:** w
- **Max Health:** 3 HP
- **Abilities:**
  - look (3 range)
  - shoot (3 range, 11 power)
- **AI:** Attack first enemy in line of sight in any direction.
